#!/usr/bin/python
#
# Copyright 2018-2021 Polyaxon, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

    Polyaxon SDKs and REST API specification.  # noqa: E501

    The version of the OpenAPI document: 1.16.1
    Contact: contact@polyaxon.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from polyaxon_sdk.configuration import Configuration


class V1MXJob(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'kind': 'str',
        'clean_pod_policy': 'V1CleanPodPolicy',
        'scheduling_policy': 'V1SchedulingPolicy',
        'mode': 'MXJobMode',
        'scheduler': 'V1KFReplica',
        'server': 'V1KFReplica',
        'worker': 'V1KFReplica',
        'tuner_tracker': 'V1KFReplica',
        'tuner_server': 'V1KFReplica',
        'tuner': 'V1KFReplica'
    }

    attribute_map = {
        'kind': 'kind',
        'clean_pod_policy': 'cleanPodPolicy',
        'scheduling_policy': 'schedulingPolicy',
        'mode': 'mode',
        'scheduler': 'scheduler',
        'server': 'server',
        'worker': 'worker',
        'tuner_tracker': 'tuner_tracker',
        'tuner_server': 'tuner_server',
        'tuner': 'tuner'
    }

    def __init__(self, kind='mxjob', clean_pod_policy=None, scheduling_policy=None, mode=None, scheduler=None, server=None, worker=None, tuner_tracker=None, tuner_server=None, tuner=None, local_vars_configuration=None):  # noqa: E501
        """V1MXJob - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._kind = None
        self._clean_pod_policy = None
        self._scheduling_policy = None
        self._mode = None
        self._scheduler = None
        self._server = None
        self._worker = None
        self._tuner_tracker = None
        self._tuner_server = None
        self._tuner = None
        self.discriminator = None

        if kind is not None:
            self.kind = kind
        if clean_pod_policy is not None:
            self.clean_pod_policy = clean_pod_policy
        if scheduling_policy is not None:
            self.scheduling_policy = scheduling_policy
        if mode is not None:
            self.mode = mode
        if scheduler is not None:
            self.scheduler = scheduler
        if server is not None:
            self.server = server
        if worker is not None:
            self.worker = worker
        if tuner_tracker is not None:
            self.tuner_tracker = tuner_tracker
        if tuner_server is not None:
            self.tuner_server = tuner_server
        if tuner is not None:
            self.tuner = tuner

    @property
    def kind(self):
        """Gets the kind of this V1MXJob.  # noqa: E501


        :return: The kind of this V1MXJob.  # noqa: E501
        :rtype: str
        """
        return self._kind

    @kind.setter
    def kind(self, kind):
        """Sets the kind of this V1MXJob.


        :param kind: The kind of this V1MXJob.  # noqa: E501
        :type kind: str
        """

        self._kind = kind

    @property
    def clean_pod_policy(self):
        """Gets the clean_pod_policy of this V1MXJob.  # noqa: E501


        :return: The clean_pod_policy of this V1MXJob.  # noqa: E501
        :rtype: V1CleanPodPolicy
        """
        return self._clean_pod_policy

    @clean_pod_policy.setter
    def clean_pod_policy(self, clean_pod_policy):
        """Sets the clean_pod_policy of this V1MXJob.


        :param clean_pod_policy: The clean_pod_policy of this V1MXJob.  # noqa: E501
        :type clean_pod_policy: V1CleanPodPolicy
        """

        self._clean_pod_policy = clean_pod_policy

    @property
    def scheduling_policy(self):
        """Gets the scheduling_policy of this V1MXJob.  # noqa: E501


        :return: The scheduling_policy of this V1MXJob.  # noqa: E501
        :rtype: V1SchedulingPolicy
        """
        return self._scheduling_policy

    @scheduling_policy.setter
    def scheduling_policy(self, scheduling_policy):
        """Sets the scheduling_policy of this V1MXJob.


        :param scheduling_policy: The scheduling_policy of this V1MXJob.  # noqa: E501
        :type scheduling_policy: V1SchedulingPolicy
        """

        self._scheduling_policy = scheduling_policy

    @property
    def mode(self):
        """Gets the mode of this V1MXJob.  # noqa: E501


        :return: The mode of this V1MXJob.  # noqa: E501
        :rtype: MXJobMode
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """Sets the mode of this V1MXJob.


        :param mode: The mode of this V1MXJob.  # noqa: E501
        :type mode: MXJobMode
        """

        self._mode = mode

    @property
    def scheduler(self):
        """Gets the scheduler of this V1MXJob.  # noqa: E501


        :return: The scheduler of this V1MXJob.  # noqa: E501
        :rtype: V1KFReplica
        """
        return self._scheduler

    @scheduler.setter
    def scheduler(self, scheduler):
        """Sets the scheduler of this V1MXJob.


        :param scheduler: The scheduler of this V1MXJob.  # noqa: E501
        :type scheduler: V1KFReplica
        """

        self._scheduler = scheduler

    @property
    def server(self):
        """Gets the server of this V1MXJob.  # noqa: E501


        :return: The server of this V1MXJob.  # noqa: E501
        :rtype: V1KFReplica
        """
        return self._server

    @server.setter
    def server(self, server):
        """Sets the server of this V1MXJob.


        :param server: The server of this V1MXJob.  # noqa: E501
        :type server: V1KFReplica
        """

        self._server = server

    @property
    def worker(self):
        """Gets the worker of this V1MXJob.  # noqa: E501


        :return: The worker of this V1MXJob.  # noqa: E501
        :rtype: V1KFReplica
        """
        return self._worker

    @worker.setter
    def worker(self, worker):
        """Sets the worker of this V1MXJob.


        :param worker: The worker of this V1MXJob.  # noqa: E501
        :type worker: V1KFReplica
        """

        self._worker = worker

    @property
    def tuner_tracker(self):
        """Gets the tuner_tracker of this V1MXJob.  # noqa: E501


        :return: The tuner_tracker of this V1MXJob.  # noqa: E501
        :rtype: V1KFReplica
        """
        return self._tuner_tracker

    @tuner_tracker.setter
    def tuner_tracker(self, tuner_tracker):
        """Sets the tuner_tracker of this V1MXJob.


        :param tuner_tracker: The tuner_tracker of this V1MXJob.  # noqa: E501
        :type tuner_tracker: V1KFReplica
        """

        self._tuner_tracker = tuner_tracker

    @property
    def tuner_server(self):
        """Gets the tuner_server of this V1MXJob.  # noqa: E501


        :return: The tuner_server of this V1MXJob.  # noqa: E501
        :rtype: V1KFReplica
        """
        return self._tuner_server

    @tuner_server.setter
    def tuner_server(self, tuner_server):
        """Sets the tuner_server of this V1MXJob.


        :param tuner_server: The tuner_server of this V1MXJob.  # noqa: E501
        :type tuner_server: V1KFReplica
        """

        self._tuner_server = tuner_server

    @property
    def tuner(self):
        """Gets the tuner of this V1MXJob.  # noqa: E501


        :return: The tuner of this V1MXJob.  # noqa: E501
        :rtype: V1KFReplica
        """
        return self._tuner

    @tuner.setter
    def tuner(self, tuner):
        """Sets the tuner of this V1MXJob.


        :param tuner: The tuner of this V1MXJob.  # noqa: E501
        :type tuner: V1KFReplica
        """

        self._tuner = tuner

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1MXJob):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1MXJob):
            return True

        return self.to_dict() != other.to_dict()



#!/usr/bin/python
#
# Copyright 2018-2021 Polyaxon, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

    Polyaxon SDKs and REST API specification.  # noqa: E501

    The version of the OpenAPI document: 1.16.1
    Contact: contact@polyaxon.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from polyaxon_sdk.configuration import Configuration


class V1Plugins(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'auth': 'bool',
        'docker': 'bool',
        'shm': 'bool',
        'mount_artifacts_store': 'bool',
        'collect_artifacts': 'bool',
        'collect_logs': 'bool',
        'collect_resources': 'str',
        'sync_statuses': 'bool',
        'auto_resume': 'bool',
        'log_level': 'str',
        'external_host': 'bool',
        'sidecar': 'V1PolyaxonSidecarContainer',
        'notifications': 'list[V1Notification]'
    }

    attribute_map = {
        'auth': 'auth',
        'docker': 'docker',
        'shm': 'shm',
        'mount_artifacts_store': 'mountArtifactsStore',
        'collect_artifacts': 'collectArtifacts',
        'collect_logs': 'collectLogs',
        'collect_resources': 'collectResources',
        'sync_statuses': 'syncStatuses',
        'auto_resume': 'autoResume',
        'log_level': 'logLevel',
        'external_host': 'externalHost',
        'sidecar': 'sidecar',
        'notifications': 'notifications'
    }

    def __init__(self, auth=None, docker=None, shm=None, mount_artifacts_store=None, collect_artifacts=None, collect_logs=None, collect_resources=None, sync_statuses=None, auto_resume=None, log_level=None, external_host=None, sidecar=None, notifications=None, local_vars_configuration=None):  # noqa: E501
        """V1Plugins - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._auth = None
        self._docker = None
        self._shm = None
        self._mount_artifacts_store = None
        self._collect_artifacts = None
        self._collect_logs = None
        self._collect_resources = None
        self._sync_statuses = None
        self._auto_resume = None
        self._log_level = None
        self._external_host = None
        self._sidecar = None
        self._notifications = None
        self.discriminator = None

        if auth is not None:
            self.auth = auth
        if docker is not None:
            self.docker = docker
        if shm is not None:
            self.shm = shm
        if mount_artifacts_store is not None:
            self.mount_artifacts_store = mount_artifacts_store
        if collect_artifacts is not None:
            self.collect_artifacts = collect_artifacts
        if collect_logs is not None:
            self.collect_logs = collect_logs
        if collect_resources is not None:
            self.collect_resources = collect_resources
        if sync_statuses is not None:
            self.sync_statuses = sync_statuses
        if auto_resume is not None:
            self.auto_resume = auto_resume
        if log_level is not None:
            self.log_level = log_level
        if external_host is not None:
            self.external_host = external_host
        if sidecar is not None:
            self.sidecar = sidecar
        if notifications is not None:
            self.notifications = notifications

    @property
    def auth(self):
        """Gets the auth of this V1Plugins.  # noqa: E501


        :return: The auth of this V1Plugins.  # noqa: E501
        :rtype: bool
        """
        return self._auth

    @auth.setter
    def auth(self, auth):
        """Sets the auth of this V1Plugins.


        :param auth: The auth of this V1Plugins.  # noqa: E501
        :type auth: bool
        """

        self._auth = auth

    @property
    def docker(self):
        """Gets the docker of this V1Plugins.  # noqa: E501


        :return: The docker of this V1Plugins.  # noqa: E501
        :rtype: bool
        """
        return self._docker

    @docker.setter
    def docker(self, docker):
        """Sets the docker of this V1Plugins.


        :param docker: The docker of this V1Plugins.  # noqa: E501
        :type docker: bool
        """

        self._docker = docker

    @property
    def shm(self):
        """Gets the shm of this V1Plugins.  # noqa: E501


        :return: The shm of this V1Plugins.  # noqa: E501
        :rtype: bool
        """
        return self._shm

    @shm.setter
    def shm(self, shm):
        """Sets the shm of this V1Plugins.


        :param shm: The shm of this V1Plugins.  # noqa: E501
        :type shm: bool
        """

        self._shm = shm

    @property
    def mount_artifacts_store(self):
        """Gets the mount_artifacts_store of this V1Plugins.  # noqa: E501


        :return: The mount_artifacts_store of this V1Plugins.  # noqa: E501
        :rtype: bool
        """
        return self._mount_artifacts_store

    @mount_artifacts_store.setter
    def mount_artifacts_store(self, mount_artifacts_store):
        """Sets the mount_artifacts_store of this V1Plugins.


        :param mount_artifacts_store: The mount_artifacts_store of this V1Plugins.  # noqa: E501
        :type mount_artifacts_store: bool
        """

        self._mount_artifacts_store = mount_artifacts_store

    @property
    def collect_artifacts(self):
        """Gets the collect_artifacts of this V1Plugins.  # noqa: E501


        :return: The collect_artifacts of this V1Plugins.  # noqa: E501
        :rtype: bool
        """
        return self._collect_artifacts

    @collect_artifacts.setter
    def collect_artifacts(self, collect_artifacts):
        """Sets the collect_artifacts of this V1Plugins.


        :param collect_artifacts: The collect_artifacts of this V1Plugins.  # noqa: E501
        :type collect_artifacts: bool
        """

        self._collect_artifacts = collect_artifacts

    @property
    def collect_logs(self):
        """Gets the collect_logs of this V1Plugins.  # noqa: E501


        :return: The collect_logs of this V1Plugins.  # noqa: E501
        :rtype: bool
        """
        return self._collect_logs

    @collect_logs.setter
    def collect_logs(self, collect_logs):
        """Sets the collect_logs of this V1Plugins.


        :param collect_logs: The collect_logs of this V1Plugins.  # noqa: E501
        :type collect_logs: bool
        """

        self._collect_logs = collect_logs

    @property
    def collect_resources(self):
        """Gets the collect_resources of this V1Plugins.  # noqa: E501


        :return: The collect_resources of this V1Plugins.  # noqa: E501
        :rtype: str
        """
        return self._collect_resources

    @collect_resources.setter
    def collect_resources(self, collect_resources):
        """Sets the collect_resources of this V1Plugins.


        :param collect_resources: The collect_resources of this V1Plugins.  # noqa: E501
        :type collect_resources: str
        """

        self._collect_resources = collect_resources

    @property
    def sync_statuses(self):
        """Gets the sync_statuses of this V1Plugins.  # noqa: E501


        :return: The sync_statuses of this V1Plugins.  # noqa: E501
        :rtype: bool
        """
        return self._sync_statuses

    @sync_statuses.setter
    def sync_statuses(self, sync_statuses):
        """Sets the sync_statuses of this V1Plugins.


        :param sync_statuses: The sync_statuses of this V1Plugins.  # noqa: E501
        :type sync_statuses: bool
        """

        self._sync_statuses = sync_statuses

    @property
    def auto_resume(self):
        """Gets the auto_resume of this V1Plugins.  # noqa: E501


        :return: The auto_resume of this V1Plugins.  # noqa: E501
        :rtype: bool
        """
        return self._auto_resume

    @auto_resume.setter
    def auto_resume(self, auto_resume):
        """Sets the auto_resume of this V1Plugins.


        :param auto_resume: The auto_resume of this V1Plugins.  # noqa: E501
        :type auto_resume: bool
        """

        self._auto_resume = auto_resume

    @property
    def log_level(self):
        """Gets the log_level of this V1Plugins.  # noqa: E501


        :return: The log_level of this V1Plugins.  # noqa: E501
        :rtype: str
        """
        return self._log_level

    @log_level.setter
    def log_level(self, log_level):
        """Sets the log_level of this V1Plugins.


        :param log_level: The log_level of this V1Plugins.  # noqa: E501
        :type log_level: str
        """

        self._log_level = log_level

    @property
    def external_host(self):
        """Gets the external_host of this V1Plugins.  # noqa: E501


        :return: The external_host of this V1Plugins.  # noqa: E501
        :rtype: bool
        """
        return self._external_host

    @external_host.setter
    def external_host(self, external_host):
        """Sets the external_host of this V1Plugins.


        :param external_host: The external_host of this V1Plugins.  # noqa: E501
        :type external_host: bool
        """

        self._external_host = external_host

    @property
    def sidecar(self):
        """Gets the sidecar of this V1Plugins.  # noqa: E501


        :return: The sidecar of this V1Plugins.  # noqa: E501
        :rtype: V1PolyaxonSidecarContainer
        """
        return self._sidecar

    @sidecar.setter
    def sidecar(self, sidecar):
        """Sets the sidecar of this V1Plugins.


        :param sidecar: The sidecar of this V1Plugins.  # noqa: E501
        :type sidecar: V1PolyaxonSidecarContainer
        """

        self._sidecar = sidecar

    @property
    def notifications(self):
        """Gets the notifications of this V1Plugins.  # noqa: E501


        :return: The notifications of this V1Plugins.  # noqa: E501
        :rtype: list[V1Notification]
        """
        return self._notifications

    @notifications.setter
    def notifications(self, notifications):
        """Sets the notifications of this V1Plugins.


        :param notifications: The notifications of this V1Plugins.  # noqa: E501
        :type notifications: list[V1Notification]
        """

        self._notifications = notifications

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1Plugins):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1Plugins):
            return True

        return self.to_dict() != other.to_dict()



#!/usr/bin/python
#
# Copyright 2018-2021 Polyaxon, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

    Polyaxon SDKs and REST API specification.  # noqa: E501

    The version of the OpenAPI document: 1.16.1
    Contact: contact@polyaxon.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from polyaxon_sdk.configuration import Configuration


class V1CompiledOperation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'version': 'float',
        'kind': 'str',
        'name': 'str',
        'description': 'str',
        'tags': 'list[str]',
        'presets': 'list[str]',
        'queue': 'str',
        'cache': 'V1Cache',
        'termination': 'V1Termination',
        'plugins': 'V1Plugins',
        'schedule': 'object',
        'events': 'list[V1EventTrigger]',
        'build': 'V1Build',
        'hooks': 'list[V1Hook]',
        'dependencies': 'list[str]',
        'trigger': 'V1TriggerPolicy',
        'conditions': 'str',
        'skip_on_upstream_skip': 'bool',
        'matrix': 'object',
        'joins': 'dict(str, V1Join)',
        'inputs': 'list[V1IO]',
        'outputs': 'list[V1IO]',
        'contexts': 'list[V1IO]',
        'is_approved': 'bool',
        'cost': 'float',
        'run': 'object'
    }

    attribute_map = {
        'version': 'version',
        'kind': 'kind',
        'name': 'name',
        'description': 'description',
        'tags': 'tags',
        'presets': 'presets',
        'queue': 'queue',
        'cache': 'cache',
        'termination': 'termination',
        'plugins': 'plugins',
        'schedule': 'schedule',
        'events': 'events',
        'build': 'build',
        'hooks': 'hooks',
        'dependencies': 'dependencies',
        'trigger': 'trigger',
        'conditions': 'conditions',
        'skip_on_upstream_skip': 'skipOnUpstreamSkip',
        'matrix': 'matrix',
        'joins': 'joins',
        'inputs': 'inputs',
        'outputs': 'outputs',
        'contexts': 'contexts',
        'is_approved': 'isApproved',
        'cost': 'cost',
        'run': 'run'
    }

    def __init__(self, version=None, kind=None, name=None, description=None, tags=None, presets=None, queue=None, cache=None, termination=None, plugins=None, schedule=None, events=None, build=None, hooks=None, dependencies=None, trigger=None, conditions=None, skip_on_upstream_skip=None, matrix=None, joins=None, inputs=None, outputs=None, contexts=None, is_approved=None, cost=None, run=None, local_vars_configuration=None):  # noqa: E501
        """V1CompiledOperation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._version = None
        self._kind = None
        self._name = None
        self._description = None
        self._tags = None
        self._presets = None
        self._queue = None
        self._cache = None
        self._termination = None
        self._plugins = None
        self._schedule = None
        self._events = None
        self._build = None
        self._hooks = None
        self._dependencies = None
        self._trigger = None
        self._conditions = None
        self._skip_on_upstream_skip = None
        self._matrix = None
        self._joins = None
        self._inputs = None
        self._outputs = None
        self._contexts = None
        self._is_approved = None
        self._cost = None
        self._run = None
        self.discriminator = None

        if version is not None:
            self.version = version
        if kind is not None:
            self.kind = kind
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if tags is not None:
            self.tags = tags
        if presets is not None:
            self.presets = presets
        if queue is not None:
            self.queue = queue
        if cache is not None:
            self.cache = cache
        if termination is not None:
            self.termination = termination
        if plugins is not None:
            self.plugins = plugins
        if schedule is not None:
            self.schedule = schedule
        if events is not None:
            self.events = events
        if build is not None:
            self.build = build
        if hooks is not None:
            self.hooks = hooks
        if dependencies is not None:
            self.dependencies = dependencies
        if trigger is not None:
            self.trigger = trigger
        if conditions is not None:
            self.conditions = conditions
        if skip_on_upstream_skip is not None:
            self.skip_on_upstream_skip = skip_on_upstream_skip
        if matrix is not None:
            self.matrix = matrix
        if joins is not None:
            self.joins = joins
        if inputs is not None:
            self.inputs = inputs
        if outputs is not None:
            self.outputs = outputs
        if contexts is not None:
            self.contexts = contexts
        if is_approved is not None:
            self.is_approved = is_approved
        if cost is not None:
            self.cost = cost
        if run is not None:
            self.run = run

    @property
    def version(self):
        """Gets the version of this V1CompiledOperation.  # noqa: E501


        :return: The version of this V1CompiledOperation.  # noqa: E501
        :rtype: float
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this V1CompiledOperation.


        :param version: The version of this V1CompiledOperation.  # noqa: E501
        :type version: float
        """

        self._version = version

    @property
    def kind(self):
        """Gets the kind of this V1CompiledOperation.  # noqa: E501


        :return: The kind of this V1CompiledOperation.  # noqa: E501
        :rtype: str
        """
        return self._kind

    @kind.setter
    def kind(self, kind):
        """Sets the kind of this V1CompiledOperation.


        :param kind: The kind of this V1CompiledOperation.  # noqa: E501
        :type kind: str
        """

        self._kind = kind

    @property
    def name(self):
        """Gets the name of this V1CompiledOperation.  # noqa: E501


        :return: The name of this V1CompiledOperation.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1CompiledOperation.


        :param name: The name of this V1CompiledOperation.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this V1CompiledOperation.  # noqa: E501


        :return: The description of this V1CompiledOperation.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this V1CompiledOperation.


        :param description: The description of this V1CompiledOperation.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def tags(self):
        """Gets the tags of this V1CompiledOperation.  # noqa: E501


        :return: The tags of this V1CompiledOperation.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this V1CompiledOperation.


        :param tags: The tags of this V1CompiledOperation.  # noqa: E501
        :type tags: list[str]
        """

        self._tags = tags

    @property
    def presets(self):
        """Gets the presets of this V1CompiledOperation.  # noqa: E501


        :return: The presets of this V1CompiledOperation.  # noqa: E501
        :rtype: list[str]
        """
        return self._presets

    @presets.setter
    def presets(self, presets):
        """Sets the presets of this V1CompiledOperation.


        :param presets: The presets of this V1CompiledOperation.  # noqa: E501
        :type presets: list[str]
        """

        self._presets = presets

    @property
    def queue(self):
        """Gets the queue of this V1CompiledOperation.  # noqa: E501


        :return: The queue of this V1CompiledOperation.  # noqa: E501
        :rtype: str
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """Sets the queue of this V1CompiledOperation.


        :param queue: The queue of this V1CompiledOperation.  # noqa: E501
        :type queue: str
        """

        self._queue = queue

    @property
    def cache(self):
        """Gets the cache of this V1CompiledOperation.  # noqa: E501


        :return: The cache of this V1CompiledOperation.  # noqa: E501
        :rtype: V1Cache
        """
        return self._cache

    @cache.setter
    def cache(self, cache):
        """Sets the cache of this V1CompiledOperation.


        :param cache: The cache of this V1CompiledOperation.  # noqa: E501
        :type cache: V1Cache
        """

        self._cache = cache

    @property
    def termination(self):
        """Gets the termination of this V1CompiledOperation.  # noqa: E501


        :return: The termination of this V1CompiledOperation.  # noqa: E501
        :rtype: V1Termination
        """
        return self._termination

    @termination.setter
    def termination(self, termination):
        """Sets the termination of this V1CompiledOperation.


        :param termination: The termination of this V1CompiledOperation.  # noqa: E501
        :type termination: V1Termination
        """

        self._termination = termination

    @property
    def plugins(self):
        """Gets the plugins of this V1CompiledOperation.  # noqa: E501


        :return: The plugins of this V1CompiledOperation.  # noqa: E501
        :rtype: V1Plugins
        """
        return self._plugins

    @plugins.setter
    def plugins(self, plugins):
        """Sets the plugins of this V1CompiledOperation.


        :param plugins: The plugins of this V1CompiledOperation.  # noqa: E501
        :type plugins: V1Plugins
        """

        self._plugins = plugins

    @property
    def schedule(self):
        """Gets the schedule of this V1CompiledOperation.  # noqa: E501


        :return: The schedule of this V1CompiledOperation.  # noqa: E501
        :rtype: object
        """
        return self._schedule

    @schedule.setter
    def schedule(self, schedule):
        """Sets the schedule of this V1CompiledOperation.


        :param schedule: The schedule of this V1CompiledOperation.  # noqa: E501
        :type schedule: object
        """

        self._schedule = schedule

    @property
    def events(self):
        """Gets the events of this V1CompiledOperation.  # noqa: E501


        :return: The events of this V1CompiledOperation.  # noqa: E501
        :rtype: list[V1EventTrigger]
        """
        return self._events

    @events.setter
    def events(self, events):
        """Sets the events of this V1CompiledOperation.


        :param events: The events of this V1CompiledOperation.  # noqa: E501
        :type events: list[V1EventTrigger]
        """

        self._events = events

    @property
    def build(self):
        """Gets the build of this V1CompiledOperation.  # noqa: E501


        :return: The build of this V1CompiledOperation.  # noqa: E501
        :rtype: V1Build
        """
        return self._build

    @build.setter
    def build(self, build):
        """Sets the build of this V1CompiledOperation.


        :param build: The build of this V1CompiledOperation.  # noqa: E501
        :type build: V1Build
        """

        self._build = build

    @property
    def hooks(self):
        """Gets the hooks of this V1CompiledOperation.  # noqa: E501


        :return: The hooks of this V1CompiledOperation.  # noqa: E501
        :rtype: list[V1Hook]
        """
        return self._hooks

    @hooks.setter
    def hooks(self, hooks):
        """Sets the hooks of this V1CompiledOperation.


        :param hooks: The hooks of this V1CompiledOperation.  # noqa: E501
        :type hooks: list[V1Hook]
        """

        self._hooks = hooks

    @property
    def dependencies(self):
        """Gets the dependencies of this V1CompiledOperation.  # noqa: E501


        :return: The dependencies of this V1CompiledOperation.  # noqa: E501
        :rtype: list[str]
        """
        return self._dependencies

    @dependencies.setter
    def dependencies(self, dependencies):
        """Sets the dependencies of this V1CompiledOperation.


        :param dependencies: The dependencies of this V1CompiledOperation.  # noqa: E501
        :type dependencies: list[str]
        """

        self._dependencies = dependencies

    @property
    def trigger(self):
        """Gets the trigger of this V1CompiledOperation.  # noqa: E501


        :return: The trigger of this V1CompiledOperation.  # noqa: E501
        :rtype: V1TriggerPolicy
        """
        return self._trigger

    @trigger.setter
    def trigger(self, trigger):
        """Sets the trigger of this V1CompiledOperation.


        :param trigger: The trigger of this V1CompiledOperation.  # noqa: E501
        :type trigger: V1TriggerPolicy
        """

        self._trigger = trigger

    @property
    def conditions(self):
        """Gets the conditions of this V1CompiledOperation.  # noqa: E501


        :return: The conditions of this V1CompiledOperation.  # noqa: E501
        :rtype: str
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this V1CompiledOperation.


        :param conditions: The conditions of this V1CompiledOperation.  # noqa: E501
        :type conditions: str
        """

        self._conditions = conditions

    @property
    def skip_on_upstream_skip(self):
        """Gets the skip_on_upstream_skip of this V1CompiledOperation.  # noqa: E501


        :return: The skip_on_upstream_skip of this V1CompiledOperation.  # noqa: E501
        :rtype: bool
        """
        return self._skip_on_upstream_skip

    @skip_on_upstream_skip.setter
    def skip_on_upstream_skip(self, skip_on_upstream_skip):
        """Sets the skip_on_upstream_skip of this V1CompiledOperation.


        :param skip_on_upstream_skip: The skip_on_upstream_skip of this V1CompiledOperation.  # noqa: E501
        :type skip_on_upstream_skip: bool
        """

        self._skip_on_upstream_skip = skip_on_upstream_skip

    @property
    def matrix(self):
        """Gets the matrix of this V1CompiledOperation.  # noqa: E501


        :return: The matrix of this V1CompiledOperation.  # noqa: E501
        :rtype: object
        """
        return self._matrix

    @matrix.setter
    def matrix(self, matrix):
        """Sets the matrix of this V1CompiledOperation.


        :param matrix: The matrix of this V1CompiledOperation.  # noqa: E501
        :type matrix: object
        """

        self._matrix = matrix

    @property
    def joins(self):
        """Gets the joins of this V1CompiledOperation.  # noqa: E501


        :return: The joins of this V1CompiledOperation.  # noqa: E501
        :rtype: dict(str, V1Join)
        """
        return self._joins

    @joins.setter
    def joins(self, joins):
        """Sets the joins of this V1CompiledOperation.


        :param joins: The joins of this V1CompiledOperation.  # noqa: E501
        :type joins: dict(str, V1Join)
        """

        self._joins = joins

    @property
    def inputs(self):
        """Gets the inputs of this V1CompiledOperation.  # noqa: E501


        :return: The inputs of this V1CompiledOperation.  # noqa: E501
        :rtype: list[V1IO]
        """
        return self._inputs

    @inputs.setter
    def inputs(self, inputs):
        """Sets the inputs of this V1CompiledOperation.


        :param inputs: The inputs of this V1CompiledOperation.  # noqa: E501
        :type inputs: list[V1IO]
        """

        self._inputs = inputs

    @property
    def outputs(self):
        """Gets the outputs of this V1CompiledOperation.  # noqa: E501


        :return: The outputs of this V1CompiledOperation.  # noqa: E501
        :rtype: list[V1IO]
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        """Sets the outputs of this V1CompiledOperation.


        :param outputs: The outputs of this V1CompiledOperation.  # noqa: E501
        :type outputs: list[V1IO]
        """

        self._outputs = outputs

    @property
    def contexts(self):
        """Gets the contexts of this V1CompiledOperation.  # noqa: E501


        :return: The contexts of this V1CompiledOperation.  # noqa: E501
        :rtype: list[V1IO]
        """
        return self._contexts

    @contexts.setter
    def contexts(self, contexts):
        """Sets the contexts of this V1CompiledOperation.


        :param contexts: The contexts of this V1CompiledOperation.  # noqa: E501
        :type contexts: list[V1IO]
        """

        self._contexts = contexts

    @property
    def is_approved(self):
        """Gets the is_approved of this V1CompiledOperation.  # noqa: E501


        :return: The is_approved of this V1CompiledOperation.  # noqa: E501
        :rtype: bool
        """
        return self._is_approved

    @is_approved.setter
    def is_approved(self, is_approved):
        """Sets the is_approved of this V1CompiledOperation.


        :param is_approved: The is_approved of this V1CompiledOperation.  # noqa: E501
        :type is_approved: bool
        """

        self._is_approved = is_approved

    @property
    def cost(self):
        """Gets the cost of this V1CompiledOperation.  # noqa: E501


        :return: The cost of this V1CompiledOperation.  # noqa: E501
        :rtype: float
        """
        return self._cost

    @cost.setter
    def cost(self, cost):
        """Sets the cost of this V1CompiledOperation.


        :param cost: The cost of this V1CompiledOperation.  # noqa: E501
        :type cost: float
        """

        self._cost = cost

    @property
    def run(self):
        """Gets the run of this V1CompiledOperation.  # noqa: E501


        :return: The run of this V1CompiledOperation.  # noqa: E501
        :rtype: object
        """
        return self._run

    @run.setter
    def run(self, run):
        """Sets the run of this V1CompiledOperation.


        :param run: The run of this V1CompiledOperation.  # noqa: E501
        :type run: object
        """

        self._run = run

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1CompiledOperation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1CompiledOperation):
            return True

        return self.to_dict() != other.to_dict()



#!/usr/bin/python
#
# Copyright 2018-2021 Polyaxon, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

    Polyaxon SDKs and REST API specification.  # noqa: E501

    The version of the OpenAPI document: 1.16.1
    Contact: contact@polyaxon.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from polyaxon_sdk.configuration import Configuration


class V1Activity(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'actor': 'str',
        'owner': 'str',
        'created_at': 'datetime',
        'event_action': 'str',
        'event_subject': 'str',
        'object_name': 'str',
        'object_uuid': 'str',
        'object_parent': 'str'
    }

    attribute_map = {
        'actor': 'actor',
        'owner': 'owner',
        'created_at': 'created_at',
        'event_action': 'event_action',
        'event_subject': 'event_subject',
        'object_name': 'object_name',
        'object_uuid': 'object_uuid',
        'object_parent': 'object_parent'
    }

    def __init__(self, actor=None, owner=None, created_at=None, event_action=None, event_subject=None, object_name=None, object_uuid=None, object_parent=None, local_vars_configuration=None):  # noqa: E501
        """V1Activity - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._actor = None
        self._owner = None
        self._created_at = None
        self._event_action = None
        self._event_subject = None
        self._object_name = None
        self._object_uuid = None
        self._object_parent = None
        self.discriminator = None

        if actor is not None:
            self.actor = actor
        if owner is not None:
            self.owner = owner
        if created_at is not None:
            self.created_at = created_at
        if event_action is not None:
            self.event_action = event_action
        if event_subject is not None:
            self.event_subject = event_subject
        if object_name is not None:
            self.object_name = object_name
        if object_uuid is not None:
            self.object_uuid = object_uuid
        if object_parent is not None:
            self.object_parent = object_parent

    @property
    def actor(self):
        """Gets the actor of this V1Activity.  # noqa: E501


        :return: The actor of this V1Activity.  # noqa: E501
        :rtype: str
        """
        return self._actor

    @actor.setter
    def actor(self, actor):
        """Sets the actor of this V1Activity.


        :param actor: The actor of this V1Activity.  # noqa: E501
        :type actor: str
        """

        self._actor = actor

    @property
    def owner(self):
        """Gets the owner of this V1Activity.  # noqa: E501


        :return: The owner of this V1Activity.  # noqa: E501
        :rtype: str
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this V1Activity.


        :param owner: The owner of this V1Activity.  # noqa: E501
        :type owner: str
        """

        self._owner = owner

    @property
    def created_at(self):
        """Gets the created_at of this V1Activity.  # noqa: E501


        :return: The created_at of this V1Activity.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this V1Activity.


        :param created_at: The created_at of this V1Activity.  # noqa: E501
        :type created_at: datetime
        """

        self._created_at = created_at

    @property
    def event_action(self):
        """Gets the event_action of this V1Activity.  # noqa: E501


        :return: The event_action of this V1Activity.  # noqa: E501
        :rtype: str
        """
        return self._event_action

    @event_action.setter
    def event_action(self, event_action):
        """Sets the event_action of this V1Activity.


        :param event_action: The event_action of this V1Activity.  # noqa: E501
        :type event_action: str
        """

        self._event_action = event_action

    @property
    def event_subject(self):
        """Gets the event_subject of this V1Activity.  # noqa: E501


        :return: The event_subject of this V1Activity.  # noqa: E501
        :rtype: str
        """
        return self._event_subject

    @event_subject.setter
    def event_subject(self, event_subject):
        """Sets the event_subject of this V1Activity.


        :param event_subject: The event_subject of this V1Activity.  # noqa: E501
        :type event_subject: str
        """

        self._event_subject = event_subject

    @property
    def object_name(self):
        """Gets the object_name of this V1Activity.  # noqa: E501


        :return: The object_name of this V1Activity.  # noqa: E501
        :rtype: str
        """
        return self._object_name

    @object_name.setter
    def object_name(self, object_name):
        """Sets the object_name of this V1Activity.


        :param object_name: The object_name of this V1Activity.  # noqa: E501
        :type object_name: str
        """

        self._object_name = object_name

    @property
    def object_uuid(self):
        """Gets the object_uuid of this V1Activity.  # noqa: E501


        :return: The object_uuid of this V1Activity.  # noqa: E501
        :rtype: str
        """
        return self._object_uuid

    @object_uuid.setter
    def object_uuid(self, object_uuid):
        """Sets the object_uuid of this V1Activity.


        :param object_uuid: The object_uuid of this V1Activity.  # noqa: E501
        :type object_uuid: str
        """

        self._object_uuid = object_uuid

    @property
    def object_parent(self):
        """Gets the object_parent of this V1Activity.  # noqa: E501


        :return: The object_parent of this V1Activity.  # noqa: E501
        :rtype: str
        """
        return self._object_parent

    @object_parent.setter
    def object_parent(self, object_parent):
        """Sets the object_parent of this V1Activity.


        :param object_parent: The object_parent of this V1Activity.  # noqa: E501
        :type object_parent: str
        """

        self._object_parent = object_parent

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1Activity):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1Activity):
            return True

        return self.to_dict() != other.to_dict()



#!/usr/bin/python
#
# Copyright 2018-2021 Polyaxon, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

    Polyaxon SDKs and REST API specification.  # noqa: E501

    The version of the OpenAPI document: 1.16.1
    Contact: contact@polyaxon.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from polyaxon_sdk.configuration import Configuration


class V1HpParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'choice': 'V1HpChoice',
        'pchoice': 'V1HpPChoice',
        'range': 'V1HpRange',
        'linspace': 'V1HpLinSpace',
        'logspace': 'V1HpLogSpace',
        'geomspace': 'V1HpGeomSpace',
        'uniform': 'V1HpUniform',
        'quniform': 'V1HpQUniform',
        'loguniform': 'V1HpLogUniform',
        'qloguniform': 'V1HpQLogUniform',
        'normal': 'V1HpNormal',
        'qnormal': 'V1HpQNormal',
        'lognormal': 'V1HpLogNormal',
        'qlognormal': 'V1HpQLogNormal',
        'daterange': 'V1HpDateRange',
        'datetimerange': 'V1HpDateTimeRange'
    }

    attribute_map = {
        'choice': 'choice',
        'pchoice': 'pchoice',
        'range': 'range',
        'linspace': 'linspace',
        'logspace': 'logspace',
        'geomspace': 'geomspace',
        'uniform': 'uniform',
        'quniform': 'quniform',
        'loguniform': 'loguniform',
        'qloguniform': 'qloguniform',
        'normal': 'normal',
        'qnormal': 'qnormal',
        'lognormal': 'lognormal',
        'qlognormal': 'qlognormal',
        'daterange': 'daterange',
        'datetimerange': 'datetimerange'
    }

    def __init__(self, choice=None, pchoice=None, range=None, linspace=None, logspace=None, geomspace=None, uniform=None, quniform=None, loguniform=None, qloguniform=None, normal=None, qnormal=None, lognormal=None, qlognormal=None, daterange=None, datetimerange=None, local_vars_configuration=None):  # noqa: E501
        """V1HpParams - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._choice = None
        self._pchoice = None
        self._range = None
        self._linspace = None
        self._logspace = None
        self._geomspace = None
        self._uniform = None
        self._quniform = None
        self._loguniform = None
        self._qloguniform = None
        self._normal = None
        self._qnormal = None
        self._lognormal = None
        self._qlognormal = None
        self._daterange = None
        self._datetimerange = None
        self.discriminator = None

        if choice is not None:
            self.choice = choice
        if pchoice is not None:
            self.pchoice = pchoice
        if range is not None:
            self.range = range
        if linspace is not None:
            self.linspace = linspace
        if logspace is not None:
            self.logspace = logspace
        if geomspace is not None:
            self.geomspace = geomspace
        if uniform is not None:
            self.uniform = uniform
        if quniform is not None:
            self.quniform = quniform
        if loguniform is not None:
            self.loguniform = loguniform
        if qloguniform is not None:
            self.qloguniform = qloguniform
        if normal is not None:
            self.normal = normal
        if qnormal is not None:
            self.qnormal = qnormal
        if lognormal is not None:
            self.lognormal = lognormal
        if qlognormal is not None:
            self.qlognormal = qlognormal
        if daterange is not None:
            self.daterange = daterange
        if datetimerange is not None:
            self.datetimerange = datetimerange

    @property
    def choice(self):
        """Gets the choice of this V1HpParams.  # noqa: E501


        :return: The choice of this V1HpParams.  # noqa: E501
        :rtype: V1HpChoice
        """
        return self._choice

    @choice.setter
    def choice(self, choice):
        """Sets the choice of this V1HpParams.


        :param choice: The choice of this V1HpParams.  # noqa: E501
        :type choice: V1HpChoice
        """

        self._choice = choice

    @property
    def pchoice(self):
        """Gets the pchoice of this V1HpParams.  # noqa: E501


        :return: The pchoice of this V1HpParams.  # noqa: E501
        :rtype: V1HpPChoice
        """
        return self._pchoice

    @pchoice.setter
    def pchoice(self, pchoice):
        """Sets the pchoice of this V1HpParams.


        :param pchoice: The pchoice of this V1HpParams.  # noqa: E501
        :type pchoice: V1HpPChoice
        """

        self._pchoice = pchoice

    @property
    def range(self):
        """Gets the range of this V1HpParams.  # noqa: E501


        :return: The range of this V1HpParams.  # noqa: E501
        :rtype: V1HpRange
        """
        return self._range

    @range.setter
    def range(self, range):
        """Sets the range of this V1HpParams.


        :param range: The range of this V1HpParams.  # noqa: E501
        :type range: V1HpRange
        """

        self._range = range

    @property
    def linspace(self):
        """Gets the linspace of this V1HpParams.  # noqa: E501


        :return: The linspace of this V1HpParams.  # noqa: E501
        :rtype: V1HpLinSpace
        """
        return self._linspace

    @linspace.setter
    def linspace(self, linspace):
        """Sets the linspace of this V1HpParams.


        :param linspace: The linspace of this V1HpParams.  # noqa: E501
        :type linspace: V1HpLinSpace
        """

        self._linspace = linspace

    @property
    def logspace(self):
        """Gets the logspace of this V1HpParams.  # noqa: E501


        :return: The logspace of this V1HpParams.  # noqa: E501
        :rtype: V1HpLogSpace
        """
        return self._logspace

    @logspace.setter
    def logspace(self, logspace):
        """Sets the logspace of this V1HpParams.


        :param logspace: The logspace of this V1HpParams.  # noqa: E501
        :type logspace: V1HpLogSpace
        """

        self._logspace = logspace

    @property
    def geomspace(self):
        """Gets the geomspace of this V1HpParams.  # noqa: E501


        :return: The geomspace of this V1HpParams.  # noqa: E501
        :rtype: V1HpGeomSpace
        """
        return self._geomspace

    @geomspace.setter
    def geomspace(self, geomspace):
        """Sets the geomspace of this V1HpParams.


        :param geomspace: The geomspace of this V1HpParams.  # noqa: E501
        :type geomspace: V1HpGeomSpace
        """

        self._geomspace = geomspace

    @property
    def uniform(self):
        """Gets the uniform of this V1HpParams.  # noqa: E501


        :return: The uniform of this V1HpParams.  # noqa: E501
        :rtype: V1HpUniform
        """
        return self._uniform

    @uniform.setter
    def uniform(self, uniform):
        """Sets the uniform of this V1HpParams.


        :param uniform: The uniform of this V1HpParams.  # noqa: E501
        :type uniform: V1HpUniform
        """

        self._uniform = uniform

    @property
    def quniform(self):
        """Gets the quniform of this V1HpParams.  # noqa: E501


        :return: The quniform of this V1HpParams.  # noqa: E501
        :rtype: V1HpQUniform
        """
        return self._quniform

    @quniform.setter
    def quniform(self, quniform):
        """Sets the quniform of this V1HpParams.


        :param quniform: The quniform of this V1HpParams.  # noqa: E501
        :type quniform: V1HpQUniform
        """

        self._quniform = quniform

    @property
    def loguniform(self):
        """Gets the loguniform of this V1HpParams.  # noqa: E501


        :return: The loguniform of this V1HpParams.  # noqa: E501
        :rtype: V1HpLogUniform
        """
        return self._loguniform

    @loguniform.setter
    def loguniform(self, loguniform):
        """Sets the loguniform of this V1HpParams.


        :param loguniform: The loguniform of this V1HpParams.  # noqa: E501
        :type loguniform: V1HpLogUniform
        """

        self._loguniform = loguniform

    @property
    def qloguniform(self):
        """Gets the qloguniform of this V1HpParams.  # noqa: E501


        :return: The qloguniform of this V1HpParams.  # noqa: E501
        :rtype: V1HpQLogUniform
        """
        return self._qloguniform

    @qloguniform.setter
    def qloguniform(self, qloguniform):
        """Sets the qloguniform of this V1HpParams.


        :param qloguniform: The qloguniform of this V1HpParams.  # noqa: E501
        :type qloguniform: V1HpQLogUniform
        """

        self._qloguniform = qloguniform

    @property
    def normal(self):
        """Gets the normal of this V1HpParams.  # noqa: E501


        :return: The normal of this V1HpParams.  # noqa: E501
        :rtype: V1HpNormal
        """
        return self._normal

    @normal.setter
    def normal(self, normal):
        """Sets the normal of this V1HpParams.


        :param normal: The normal of this V1HpParams.  # noqa: E501
        :type normal: V1HpNormal
        """

        self._normal = normal

    @property
    def qnormal(self):
        """Gets the qnormal of this V1HpParams.  # noqa: E501


        :return: The qnormal of this V1HpParams.  # noqa: E501
        :rtype: V1HpQNormal
        """
        return self._qnormal

    @qnormal.setter
    def qnormal(self, qnormal):
        """Sets the qnormal of this V1HpParams.


        :param qnormal: The qnormal of this V1HpParams.  # noqa: E501
        :type qnormal: V1HpQNormal
        """

        self._qnormal = qnormal

    @property
    def lognormal(self):
        """Gets the lognormal of this V1HpParams.  # noqa: E501


        :return: The lognormal of this V1HpParams.  # noqa: E501
        :rtype: V1HpLogNormal
        """
        return self._lognormal

    @lognormal.setter
    def lognormal(self, lognormal):
        """Sets the lognormal of this V1HpParams.


        :param lognormal: The lognormal of this V1HpParams.  # noqa: E501
        :type lognormal: V1HpLogNormal
        """

        self._lognormal = lognormal

    @property
    def qlognormal(self):
        """Gets the qlognormal of this V1HpParams.  # noqa: E501


        :return: The qlognormal of this V1HpParams.  # noqa: E501
        :rtype: V1HpQLogNormal
        """
        return self._qlognormal

    @qlognormal.setter
    def qlognormal(self, qlognormal):
        """Sets the qlognormal of this V1HpParams.


        :param qlognormal: The qlognormal of this V1HpParams.  # noqa: E501
        :type qlognormal: V1HpQLogNormal
        """

        self._qlognormal = qlognormal

    @property
    def daterange(self):
        """Gets the daterange of this V1HpParams.  # noqa: E501


        :return: The daterange of this V1HpParams.  # noqa: E501
        :rtype: V1HpDateRange
        """
        return self._daterange

    @daterange.setter
    def daterange(self, daterange):
        """Sets the daterange of this V1HpParams.


        :param daterange: The daterange of this V1HpParams.  # noqa: E501
        :type daterange: V1HpDateRange
        """

        self._daterange = daterange

    @property
    def datetimerange(self):
        """Gets the datetimerange of this V1HpParams.  # noqa: E501


        :return: The datetimerange of this V1HpParams.  # noqa: E501
        :rtype: V1HpDateTimeRange
        """
        return self._datetimerange

    @datetimerange.setter
    def datetimerange(self, datetimerange):
        """Sets the datetimerange of this V1HpParams.


        :param datetimerange: The datetimerange of this V1HpParams.  # noqa: E501
        :type datetimerange: V1HpDateTimeRange
        """

        self._datetimerange = datetimerange

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1HpParams):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1HpParams):
            return True

        return self.to_dict() != other.to_dict()
